@@ -45,5 +45,5 @@ class SriovNetworkNodeState(NamespacedResource):
                 if sample == wanted_status:
                     return
         except TimeoutExpiredError:
-            self.logger.error(f"after {timeout} seconds, {self.name} status is {self.instance.status.syncStatus}")
+            self.logger.error(f"after {timeout} seconds, {self.name} status is" f" {self.instance.status.syncStatus}")
             raise
